@@ -9,6 +9,7 @@ import copy
 import enum
 import difflib
 from pathlib import Path
+from typing import Hashable
 
 import sqlalchemy as sa
 from sqlalchemy.orm import aliased
@@ -139,7 +140,8 @@ class BIDSLayout(object):
             if description and description.get("DatasetType") == "derivative":
                 if validate:
                     validate_derivative_paths([root], self)
-                config = ["bids", "derivatives"]
+                if not config:
+                    config = ["bids", "derivatives"]
 
             init_args = dict(root=root, absolute_paths=absolute_paths,
                              derivatives=derivatives, config=config)
@@ -160,7 +162,7 @@ class BIDSLayout(object):
                 validate=validate, absolute_paths=absolute_paths,
                 derivatives=None, sources=self, config=None,
                 regex_search=regex_search, reset_database=reset_database,
-                indexer=indexer, **indexer_kwargs)
+                **indexer_kwargs)
 
     @property
     def root(self):
@@ -476,11 +478,13 @@ class BIDSLayout(object):
         kwargs['config'] = kwargs.get('config') or ['bids', 'derivatives']
         kwargs['sources'] = kwargs.get('sources') or self
 
+        # TODO: Derivatives cannot be validated
+        kwargs.pop("validate", None)
         for name, deriv in deriv_paths.items():
             if parent_database_path:
                 child_database_path = parent_database_path / name
                 kwargs['database_path'] = child_database_path
-            self.derivatives[name] = BIDSLayout(deriv, **kwargs)
+            self.derivatives[name] = BIDSLayout(deriv, validate=False, **kwargs)
 
     def to_df(self, metadata=False, **filters):
         """Return information for BIDSFiles tracked in Layout as pd.DataFrame.
@@ -530,7 +534,6 @@ class BIDSLayout(object):
             data.loc[o] = pd.Series(dtype=float)
 
         return data.reset_index()
-
     def get(self, return_type='object', target=None, scope='all',
             regex_search=False, absolute_paths=None, invalid_filters='error',
             **filters):
@@ -670,13 +673,11 @@ class BIDSLayout(object):
                 raise TargetError('If return_type is "id" or "dir", a valid '
                                  'target entity must also be specified.')
 
-            metadata = target not in self.get_entities(metadata=False)
-
             if return_type == 'id':
-                ent_iter = (x.get_entities(metadata=metadata) for x in results)
-                results = list({
-                    ents[target] for ents in ent_iter if target in ents
-                })
+                results = list(dict.fromkeys(
+                    res.entities[target] for res in results
+                    if target in res.entities and isinstance(res.entities[target], Hashable)
+                ))
 
             elif return_type == 'dir':
                 template = entities[target].directory
